@@ -1,6 +1,6 @@
 /*
 explosive-c4
-Copyright (C) 2014-2022 Salvo "LtWorf" Tomaselli
+Copyright (C) 2014-2024 Salvo "LtWorf" Tomaselli
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
@@ -62,6 +62,7 @@ void Board::init(int rows, int cols, player_t initial) {
     this->cols = cols;
     this->size = rows*cols;
     this->free_cells = rows*cols;
+    this->last_column_played = -1;
 
     this->internal_board = new cell_t[size];
     memset(internal_board, 0, size*sizeof(cell_t));
@@ -131,6 +132,7 @@ bool Board::place(int col, player_t player) {
         return false;
     }
 
+    this->last_column_played = col;
     this->internal_board[col+row*cols] = (cell_t)player;
     turn = (player_t)~turn;
     emit changed(row,col);
@@ -302,3 +304,11 @@ cell_t Board::get_content(int row, int col) {
     else
         return CELL_EMPTY;
 }
+
+/**
+ * @brief Board::get_last_column_played
+ * @return -1 initially, or the last column that had a move
+ */
+int Board::get_last_column_played() {
+    return this->last_column_played;
+}
