@@ -1,6 +1,6 @@
 /*
 explosive-c4
-Copyright (C) 2014-2022 Salvo "LtWorf" Tomaselli
+Copyright (C) 2014-2024 Salvo "LtWorf" Tomaselli
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
@@ -48,6 +48,7 @@ public:
     virtual bool place(int col, player_t player);
     cell_t get_content(int row, int col);
     player_t get_turn();
+    int get_last_column_played();
 
     void dump();
 
@@ -56,6 +57,7 @@ protected:
     int cols;
     int size;
     int free_cells;
+    int last_column_played;
     cell_t *internal_board;
 
     player_t turn = PLAYER_RED;
