@@ -1,6 +1,6 @@
 /*
 explosive-c4
-Copyright (C) 2014-2022 Salvo "LtWorf" Tomaselli
+Copyright (C) 2014-2024 Salvo "LtWorf" Tomaselli
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
@@ -35,11 +35,15 @@ static QMap<cell_t, QPair<QColor, QColor> > cell_color;
 static const QColor board_color0 = QColor("#434343");
 static const QColor board_color1 = QColor("#333333");
 
+static const QColor marker_color0 = QColor("#DDDDFF");
+static const QColor marker_color1 = QColor("#CCCCFF");
+
 static const QColor win_color0 = QColor("#f3f3f3");
 static const QColor win_color1 = QColor("#030303");
 
 static QLinearGradient board_gradient, ring_gradient;
 static QLinearGradient win_gradient, ring_win_gradient;
+static QLinearGradient marker_gradient;
 
 BoardWidget::BoardWidget(boardwidget_t board_type) {
     QWidget();
@@ -68,6 +72,12 @@ BoardWidget::BoardWidget(boardwidget_t board_type) {
         ring_win_gradient = win_gradient;
         ring_win_gradient.setColorAt(0, win_color1);
         ring_win_gradient.setColorAt(1, win_color0);
+
+        marker_gradient.setStart(0.4, 0.1);
+        marker_gradient.setFinalStop(0.7,0.9);
+        marker_gradient.setCoordinateMode(QGradient::ObjectMode);
+        marker_gradient.setColorAt(0, marker_color0);
+        marker_gradient.setColorAt(1, marker_color1);
     }
 
     init();
@@ -173,12 +183,18 @@ void BoardWidget::paintEvent(QPaintEvent * p) {
 
             painter.drawEllipse(x_corner + hole_offset, y_corner + hole_offset, hole_diam, hole_diam);
 
-	    if (ring_offset > 0) {
-		    painter.setPen( QPen((winner_pos ? ring_win_gradient : ring_gradient), ring_offset) );
-		    painter.setBrush( Qt::NoBrush );
-		    painter.drawEllipse(x_corner + ring_offset, y_corner + ring_offset, ring_diam, ring_diam);
-	    }
+            if (ring_offset > 0) {
+                painter.setPen( QPen((winner_pos ? ring_win_gradient : ring_gradient), ring_offset) );
+                painter.setBrush( Qt::NoBrush );
+                painter.drawEllipse(x_corner + ring_offset, y_corner + ring_offset, ring_diam, ring_diam);
+            }
 
+            if (board->get_last_column_played() == c) {
+                // Marker for last column played
+                painter.setPen(QPen((marker_gradient), ring_offset) );
+                painter.setBrush( Qt::NoBrush );
+                painter.drawEllipse((margin_x + diameter * c) + (diameter/2) - (diameter/10), margin_y - diameter / 4, diameter/5, diameter/5);
+            }
         }
 
     }
@@ -187,12 +203,12 @@ void BoardWidget::paintEvent(QPaintEvent * p) {
 
 void BoardWidget::changed(int row, int col) {
     update(margin_x + col*diameter, margin_y + row*diameter, diameter, diameter);
+    update(0, margin_y - diameter, this->size().width(), diameter);
 }
 
 
 void BoardWidget::mousePressEvent(QMouseEvent *ev) {
-    QWidget::mousePressEvent(ev);
-    int column = (ev->position().x() - margin_x) / diameter;
+    int column = (ev->pos().x() - margin_x) / diameter;
 
     int rows;
     int cols;
